<?php

namespace Litecms\Faqcategory\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Faqcategory\Interfaces\FaqcategoryRepositoryInterface;

class FaqcategoryPublicController extends BaseController
{
    // use FaqcategoryWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Faqcategory\Interfaces\FaqcategoryRepositoryInterface $faqcategory
     *
     * @return type
     */
    public function __construct(FaqcategoryRepositoryInterface $faqcategory)
    {
        $this->repository = $faqcategory;
        parent::__construct();
    }

    /**
     * Show faqcategory's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $faqcategories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$faqcategory::$faqcategory.names'))
            ->view('$faqcategory::public.faqcategory.index')
            ->data(compact('$faqcategories'))
            ->output();
    }

    /**
     * Show faqcategory's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $faqcategories = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$faqcategory::$faqcategory.names'))
            ->view('$faqcategory::public.faqcategory.index')
            ->data(compact('$faqcategories'))
            ->output();
    }

    /**
     * Show faqcategory.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $faqcategory = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$faqcategory->name . trans('$faqcategory::$faqcategory.name'))
            ->view('$faqcategory::public.faqcategory.show')
            ->data(compact('$faqcategory'))
            ->output();
    }

}
