<?php

namespace Litecms\Faqcategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Faqcategory\Models\Faqcategory;

class FaqcategoryPolicy
{

    /**
     * Determine if the given user can view the faqcategory.
     *
     * @param UserPolicy $user
     * @param Faqcategory $faqcategory
     *
     * @return bool
     */
    public function view(UserPolicy $user, Faqcategory $faqcategory)
    {
        if ($user->canDo('faqcategory.faqcategory.view') && $user->isAdmin()) {
            return true;
        }

        return $faqcategory->user_id == user_id() && $faqcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can create a faqcategory.
     *
     * @param UserPolicy $user
     * @param Faqcategory $faqcategory
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('faqcategory.faqcategory.create');
    }

    /**
     * Determine if the given user can update the given faqcategory.
     *
     * @param UserPolicy $user
     * @param Faqcategory $faqcategory
     *
     * @return bool
     */
    public function update(UserPolicy $user, Faqcategory $faqcategory)
    {
        if ($user->canDo('faqcategory.faqcategory.edit') && $user->isAdmin()) {
            return true;
        }

        return $faqcategory->user_id == user_id() && $faqcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given faqcategory.
     *
     * @param UserPolicy $user
     * @param Faqcategory $faqcategory
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Faqcategory $faqcategory)
    {
        return $faqcategory->user_id == user_id() && $faqcategory->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given faqcategory.
     *
     * @param UserPolicy $user
     * @param Faqcategory $faqcategory
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Faqcategory $faqcategory)
    {
        if ($user->canDo('faqcategory.faqcategory.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given faqcategory.
     *
     * @param UserPolicy $user
     * @param Faqcategory $faqcategory
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Faqcategory $faqcategory)
    {
        if ($user->canDo('faqcategory.faqcategory.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
