<?php

namespace Litecms\Faqcategory\Providers;

use Illuminate\Support\ServiceProvider;

class FaqcategoryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'faqcategory');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'faqcategory');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.faqcategory', function ($app) {
            return $this->app->make('Litecms\Faqcategory\Faqcategory');
        });

                // Bind Faqcategory to repository
        $this->app->bind(
            'Litecms\Faqcategory\Interfaces\FaqcategoryRepositoryInterface',
            \Litecms\Faqcategory\Repositories\Eloquent\FaqcategoryRepository::class
        );

        $this->app->register(\Litecms\Faqcategory\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Faqcategory\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.faqcategory'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/faqcategory.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/faqcategory')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/faqcategory')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
